ResourceLocator (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

## org.openqa.selenium.server
Interface ResourceLocator

All Known Implementing Classes:
  ClasspathResourceLocator, FsResourceLocator

    public interface ResourceLocator

Method Summary
`org.mortbay.util.Resource` | `getResource(org.mortbay.http.HttpContext context, java.lang.String pathInContext)`

Method Detail

### getResource

    org.mortbay.util.Resource getResource(org.mortbay.http.HttpContext context,
                                          java.lang.String pathInContext)
                                          throws java.io.IOException

  Throws:
    `java.io.IOException`

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

Copyright © 2009. All Rights Reserved.